
Logging validation failures
-------

**Description:**

When you log all the input validation failures in your application you can discover in an 
early stage that your application is under attack and take quick countermeasures against 
the attackers. 


**Solution:**

Verify that all input validation failures are logged in order to counter possible attacks 
in an early stage. Also you want to verify that error handling logic in security controls 
denies access by default.

	